@@ -218,6 +218,15 @@ COLLECTION_REFERENCES = {
     "MAG_CS": ("https://doi.org/10.1186/s40623-020-01171-9",),
     "MAG_GRACE": ("https://doi.org/10.1186/s40623-021-01373-9",),
     "MAG_GFO": ("https://doi.org/10.1186/s40623-021-01364-w",),
+    "EFI_TIE": (
+        "https://earth.esa.int/eogateway/activities/swarm-ion-temperature-estimation",
+    ),
+    "EFI_TCT02": (
+        "https://earth.esa.int/eogateway/documents/20142/37627/swarm-EFI-TII-cross-track-flow-dataset-release-notes.pdf",
+    ),
+    "EFI_TCT16": (
+        "https://earth.esa.int/eogateway/documents/20142/37627/swarm-EFI-TII-cross-track-flow-dataset-release-notes.pdf",
+    ),
 }
 for mission in ("SW", "OR", "CH", "CR", "CO"):
     for cadence in ("1M", "4M"):
@@ -467,6 +476,9 @@ class SwarmRequest(ClientRequest):
         "MAG": [f"SW_OPER_MAG{x}_LR_1B" for x in "ABC"],
         "MAG_HR": [f"SW_OPER_MAG{x}_HR_1B" for x in "ABC"],
         "EFI": [f"SW_OPER_EFI{x}_LP_1B" for x in "ABC"],
+        "EFI_TIE": [f"SW_OPER_EFI{x}TIE_2_" for x in "ABC"],
+        "EFI_TCT02": [f"SW_EXPT_EFI{x}_TCT02" for x in "ABC"],
+        "EFI_TCT16": [f"SW_EXPT_EFI{x}_TCT16" for x in "ABC"],
         "IBI": [f"SW_OPER_IBI{x}TMS_2F" for x in "ABC"],
         "TEC": [f"SW_OPER_TEC{x}TMS_2F" for x in "ABC"],
         "FAC": [f"SW_OPER_FAC{x}TMS_2F" for x in "ABC_"],
@@ -621,6 +633,9 @@ class SwarmRequest(ClientRequest):
         "MAG": "PT1S",
         "MAG_HR": "PT0.019S",  # approx 50Hz (the sampling is not exactly 50Hz)
         "EFI": "PT0.5S",
+        "EFI_TIE": "PT0.5S",
+        "EFI_TCT02": "PT0.5S",
+        "EFI_TCT16": "PT0.0625S",
         "IBI": "PT1S",
         "TEC": "PT1S",  # Actually more complicated
         "FAC": "PT1S",
@@ -706,6 +721,78 @@ class SwarmRequest(ClientRequest):
             "Flags_Te",
             "Flags_Vs",
         ],
+        "EFI_TIE": [
+            "Latitude_GD",
+            "Longitude_GD",
+            "Height_GD",
+            "Radius_GC",
+            "Latitude_QD",
+            "MLT_QD",
+            "Tn_msis",
+            "Te_adj_LP",
+            "Ti_meas_drift",
+            "Ti_model_drift",
+            "Flag_ti_meas",
+            "Flag_ti_model",
+        ],
+        "EFI_TCT02": [  # identical to EFI_TCT16
+            "VsatC",
+            "VsatE",
+            "VsatN",
+            "Bx",
+            "By",
+            "Bz",
+            "Ehx",
+            "Ehy",
+            "Ehz",
+            "Evx",
+            "Evy",
+            "Evz",
+            "Vicrx",
+            "Vicry",
+            "Vicrz",
+            "Vixv",
+            "Vixh",
+            "Viy",
+            "Viz",
+            "Vixv_error",
+            "Vixh_error",
+            "Viy_error",
+            "Viz_error",
+            "Latitude_QD",
+            "MLT_QD",
+            "Calibration_flags",
+            "Quality_flags",
+        ],
+        "EFI_TCT16": [  # identical to EFI_TCT02
+            "VsatC",
+            "VsatE",
+            "VsatN",
+            "Bx",
+            "By",
+            "Bz",
+            "Ehx",
+            "Ehy",
+            "Ehz",
+            "Evx",
+            "Evy",
+            "Evz",
+            "Vicrx",
+            "Vicry",
+            "Vicrz",
+            "Vixv",
+            "Vixh",
+            "Viy",
+            "Viz",
+            "Vixv_error",
+            "Vixh_error",
+            "Viy_error",
+            "Viz_error",
+            "Latitude_QD",
+            "MLT_QD",
+            "Calibration_flags",
+            "Quality_flags",
+        ],
         "IBI": [
             "Bubble_Index",
             "Bubble_Probability",
@@ -1779,7 +1866,7 @@ class SwarmRequest(ClientRequest):
         mission2="Swarm",
     ):
         """Get times of the spacecraft conjunctions.
-        
+
         Currently available for the following spacecraft pairs:
           - Swarm-A/Swarm-B
 
